import { Card } from '@/components/ui/card';
import {
  Table,
  TableBody,
  TableCell,
  TableHead,
  TableHeader,
  TableRow,
} from '@/components/ui/table';
import { Badge } from '@/components/ui/badge';
import { TrendingUp, TrendingDown } from 'lucide-react';
import { formatTimeShort, getSignalBgColor } from '@/lib/utils';
import { useQuery } from '@tanstack/react-query';
import { useWebSocket } from '@/hooks/useWebSocket';
import { useEffect, useState } from 'react';
import type { Signal } from '@shared/schema';

export function SignalHistory() {
  const [signals, setSignals] = useState<Signal[]>([]);
  const { lastMessage } = useWebSocket();
  
  const { data: initialSignals, isLoading } = useQuery({
    queryKey: ['/api/signals/recent'],
    refetchInterval: 30000,
  });

  // Initialize signals from API
  useEffect(() => {
    if (initialSignals) {
      setSignals(initialSignals);
    }
  }, [initialSignals]);

  // Update signals when results come in via WebSocket
  useEffect(() => {
    if (lastMessage?.type === 'signal_result_update') {
      const { id, result, pnl } = lastMessage.data;
      setSignals(prev => prev.map(signal => 
        signal.id === id 
          ? { ...signal, result, pnl }
          : signal
      ));
    }
  }, [lastMessage]);

  const getResultColor = (result: string | null) => {
    if (result === 'WIN') return 'text-trading-success';
    if (result === 'LOSS') return 'text-trading-danger';
    return 'text-trading-muted';
  };

  const getPnlColor = (pnl: number | null) => {
    if (!pnl) return 'text-trading-muted';
    return pnl > 0 ? 'text-trading-success' : 'text-trading-danger';
  };

  if (isLoading) {
    return (
      <Card className="bg-trading-gray rounded-xl p-6">
        <h3 className="text-lg font-semibold mb-4">Signal History</h3>
        <div className="animate-pulse">
          <div className="h-4 bg-trading-slate rounded mb-4"></div>
          {[...Array(5)].map((_, i) => (
            <div key={i} className="h-8 bg-trading-slate rounded mb-2"></div>
          ))}
        </div>
      </Card>
    );
  }

  return (
    <Card className="bg-trading-gray rounded-xl p-6">
      <h3 className="text-lg font-semibold mb-4">Signal History</h3>
      
      {!signals || signals.length === 0 ? (
        <div className="text-center text-trading-muted py-8">
          <div className="text-4xl mb-2">📈</div>
          <p>No signal history available</p>
          <p className="text-sm mt-1">Signals will appear here once generated</p>
        </div>
      ) : (
        <div className="overflow-x-auto">
          <Table>
            <TableHeader>
              <TableRow className="border-trading-light hover:bg-trading-light">
                <TableHead className="text-trading-muted">Time</TableHead>
                <TableHead className="text-trading-muted">Pair</TableHead>
                <TableHead className="text-trading-muted">Direction</TableHead>
                <TableHead className="text-trading-muted">Confidence</TableHead>
                <TableHead className="text-trading-muted">Result</TableHead>
                <TableHead className="text-trading-muted">P&L</TableHead>
              </TableRow>
            </TableHeader>
            <TableBody>
              {signals.slice(0, 10).map((signal: Signal) => (
                <TableRow key={signal.id} className="border-trading-slate hover:bg-trading-slate/50">
                  <TableCell className="font-mono text-sm">
                    {formatTimeShort(new Date(signal.timestamp))}
                  </TableCell>
                  <TableCell className="font-medium">{signal.pair}</TableCell>
                  <TableCell>
                    <Badge
                      className={`${getSignalBgColor(signal.direction)} ${
                        signal.direction === 'CALL' ? 'text-trading-dark' : 'text-white'
                      } font-semibold`}
                    >
                      {signal.direction === 'CALL' ? (
                        <TrendingUp className="w-3 h-3 mr-1" />
                      ) : (
                        <TrendingDown className="w-3 h-3 mr-1" />
                      )}
                      {signal.direction}
                    </Badge>
                  </TableCell>
                  <TableCell className="font-mono text-trading-warning">
                    {signal.confidence}%
                  </TableCell>
                  <TableCell>
                    <span className={getResultColor(signal.result)}>
                      {signal.result || 'PENDING'}
                    </span>
                  </TableCell>
                  <TableCell className={`font-mono ${getPnlColor(signal.pnl)}`}>
                    {signal.pnl ? (
                      `${signal.pnl > 0 ? '+' : ''}$${signal.pnl.toFixed(2)}`
                    ) : (
                      '--'
                    )}
                  </TableCell>
                </TableRow>
              ))}
            </TableBody>
          </Table>
        </div>
      )}
    </Card>
  );
}
