import { useEffect, useRef, useState } from 'react';
import { Card } from '@/components/ui/card';
import { Select, SelectContent, SelectItem, SelectTrigger, SelectValue } from '@/components/ui/select';
import { formatPrice } from '@/lib/utils';
import { useQuery } from '@tanstack/react-query';
import type { CandleData } from '@shared/schema';

interface SimpleChartProps {
  pair: string;
  onPairChange: (pair: string) => void;
}

const CURRENCY_PAIRS = ['EUR/USD', 'GBP/USD', 'USD/JPY', 'AUD/USD', 'USD/CAD', 'GBP/JPY', 'BTC/USD OTC'];

export function SimpleChart({ pair, onPairChange }: SimpleChartProps) {
  const canvasRef = useRef<HTMLCanvasElement>(null);
  const [currentPrice, setCurrentPrice] = useState<number>(0);

  const { data: candleData } = useQuery({
    queryKey: ['/api/candle-data', pair],
    refetchInterval: 10000,
  });

  // Update current price from candle data
  useEffect(() => {
    if (candleData && candleData.length > 0) {
      const lastCandle = candleData[candleData.length - 1];
      setCurrentPrice(lastCandle.close);
    }
  }, [candleData]);

  useEffect(() => {
    if (!candleData || !canvasRef.current || candleData.length === 0) return;

    const canvas = canvasRef.current;
    const ctx = canvas.getContext('2d');
    if (!ctx) return;

    // Set canvas size
    const rect = canvas.getBoundingClientRect();
    canvas.width = rect.width * window.devicePixelRatio;
    canvas.height = rect.height * window.devicePixelRatio;
    ctx.scale(window.devicePixelRatio, window.devicePixelRatio);

    // Clear canvas
    ctx.fillStyle = 'hsl(210, 6%, 10%)'; // trading-gray
    ctx.fillRect(0, 0, rect.width, rect.height);

    // Calculate price range
    const prices = candleData.flatMap(c => [c.open, c.high, c.low, c.close]);
    const minPrice = Math.min(...prices);
    const maxPrice = Math.max(...prices);
    const priceRange = maxPrice - minPrice;
    const padding = priceRange * 0.1;
    const adjustedMin = minPrice - padding;
    const adjustedMax = maxPrice + padding;
    const adjustedRange = adjustedMax - adjustedMin;

    // Chart dimensions
    const chartWidth = rect.width - 80;
    const chartHeight = rect.height - 60;
    const chartLeft = 60;
    const chartTop = 30;

    // Draw grid lines
    ctx.strokeStyle = 'hsl(210, 6%, 21%)'; // trading-light
    ctx.lineWidth = 0.5;
    
    // Horizontal grid lines
    for (let i = 0; i <= 5; i++) {
      const y = chartTop + (chartHeight / 5) * i;
      ctx.beginPath();
      ctx.moveTo(chartLeft, y);
      ctx.lineTo(chartLeft + chartWidth, y);
      ctx.stroke();
      
      // Price labels
      const price = adjustedMax - (adjustedRange / 5) * i;
      ctx.fillStyle = 'hsl(210, 6%, 50%)'; // trading-muted
      ctx.font = '12px JetBrains Mono';
      ctx.textAlign = 'right';
      ctx.fillText(formatPrice(price, pair), chartLeft - 5, y + 4);
    }

    // Draw candlesticks
    const candleWidth = Math.max(2, chartWidth / candleData.length * 0.8);
    
    candleData.forEach((candle, index) => {
      const x = chartLeft + (chartWidth / (candleData.length - 1)) * index;
      const openY = chartTop + chartHeight - ((candle.open - adjustedMin) / adjustedRange) * chartHeight;
      const closeY = chartTop + chartHeight - ((candle.close - adjustedMin) / adjustedRange) * chartHeight;
      const highY = chartTop + chartHeight - ((candle.high - adjustedMin) / adjustedRange) * chartHeight;
      const lowY = chartTop + chartHeight - ((candle.low - adjustedMin) / adjustedRange) * chartHeight;
      
      const isGreen = candle.close >= candle.open;
      ctx.strokeStyle = isGreen ? 'hsl(174, 100%, 42%)' : 'hsl(359, 85%, 63%)'; // trading-success : trading-danger
      ctx.fillStyle = isGreen ? 'hsl(174, 100%, 42%)' : 'hsl(359, 85%, 63%)';
      ctx.lineWidth = 1;
      
      // Draw wick
      ctx.beginPath();
      ctx.moveTo(x, highY);
      ctx.lineTo(x, lowY);
      ctx.stroke();
      
      // Draw body
      const bodyTop = Math.min(openY, closeY);
      const bodyHeight = Math.abs(closeY - openY);
      
      ctx.fillRect(x - candleWidth / 2, bodyTop, candleWidth, Math.max(1, bodyHeight));
    });

    // Draw current price line
    if (currentPrice > 0) {
      const priceY = chartTop + chartHeight - ((currentPrice - adjustedMin) / adjustedRange) * chartHeight;
      ctx.strokeStyle = 'hsl(38, 92%, 50%)'; // trading-warning
      ctx.lineWidth = 2;
      ctx.setLineDash([5, 5]);
      ctx.beginPath();
      ctx.moveTo(chartLeft, priceY);
      ctx.lineTo(chartLeft + chartWidth, priceY);
      ctx.stroke();
      ctx.setLineDash([]);
      
      // Price label
      ctx.fillStyle = 'hsl(38, 92%, 50%)';
      ctx.font = 'bold 12px JetBrains Mono';
      ctx.textAlign = 'left';
      ctx.fillText(formatPrice(currentPrice, pair), chartLeft + chartWidth + 5, priceY + 4);
    }

  }, [candleData, pair, currentPrice]);

  return (
    <Card className="bg-trading-gray rounded-xl p-6">
      <div className="flex items-center justify-between mb-4">
        <div className="flex items-center space-x-4">
          <h3 className="text-lg font-semibold">{pair}</h3>
          <Select value={pair} onValueChange={onPairChange}>
            <SelectTrigger className="w-40 bg-trading-light border-trading-slate">
              <SelectValue />
            </SelectTrigger>
            <SelectContent className="bg-trading-light border-trading-slate">
              {CURRENCY_PAIRS.map(p => (
                <SelectItem key={p} value={p}>{p}</SelectItem>
              ))}
            </SelectContent>
          </Select>
        </div>
        <div className="text-right">
          <div className="text-sm text-trading-muted">Live Price</div>
          <div className="font-mono text-xl font-semibold text-trading-warning">
            {formatPrice(currentPrice, pair)}
          </div>
        </div>
      </div>
      
      <div className="relative">
        <canvas
          ref={canvasRef}
          className="w-full rounded"
          style={{ height: '400px' }}
        />
      </div>
    </Card>
  );
}