import { useEffect, useRef, useState } from 'react';
import { Card } from '@/components/ui/card';
import { Select, SelectContent, SelectItem, SelectTrigger, SelectValue } from '@/components/ui/select';
import { Button } from '@/components/ui/button';
import { BarChart3, TrendingUp } from 'lucide-react';
import { formatPrice, formatPriceChange } from '@/lib/utils';
import { usePriceUpdates } from '@/hooks/useWebSocket';
import { useQuery } from '@tanstack/react-query';
import type { CandleData } from '@shared/schema';

interface TradingChartProps {
  selectedPair: string;
  onPairChange: (pair: string) => void;
}

export function TradingChart({ selectedPair, onPairChange }: TradingChartProps) {
  const canvasRef = useRef<HTMLCanvasElement>(null);
  const [chartType, setChartType] = useState<'candlestick' | 'line'>('candlestick');
  const [timeframe, setTimeframe] = useState('1m');
  const [currentPrice, setCurrentPrice] = useState<number>(0);
  const [priceChange, setPriceChange] = useState<number>(0);
  
  const priceUpdates = usePriceUpdates();

  const { data: candleData } = useQuery({
    queryKey: ['/api/candle-data', selectedPair],
    refetchInterval: 60000, // Refetch every minute for new candles
  });

  // Update current price from real-time updates
  useEffect(() => {
    const update = priceUpdates.find(u => u.pair === selectedPair);
    if (update) {
      const previousPrice = currentPrice;
      setCurrentPrice(update.price);
      if (previousPrice > 0) {
        setPriceChange(update.price - previousPrice);
      }
    }
  }, [priceUpdates, selectedPair, currentPrice]);

  // Initialize current price from candle data
  useEffect(() => {
    if (candleData && candleData.length > 0 && currentPrice === 0) {
      const lastCandle = candleData[candleData.length - 1];
      setCurrentPrice(lastCandle.close);
    }
  }, [candleData, currentPrice]);

  useEffect(() => {
    if (!candleData || !canvasRef.current) return;

    const canvas = canvasRef.current;
    const ctx = canvas.getContext('2d');
    if (!ctx) return;

    // Set canvas size
    const rect = canvas.getBoundingClientRect();
    canvas.width = rect.width * window.devicePixelRatio;
    canvas.height = rect.height * window.devicePixelRatio;
    ctx.scale(window.devicePixelRatio, window.devicePixelRatio);

    // Clear canvas
    ctx.fillStyle = 'hsl(var(--trading-gray))';
    ctx.fillRect(0, 0, rect.width, rect.height);

    if (candleData.length === 0) return;

    // Calculate price range
    const prices = candleData.flatMap(c => [c.open, c.high, c.low, c.close]);
    const minPrice = Math.min(...prices);
    const maxPrice = Math.max(...prices);
    const priceRange = maxPrice - minPrice;
    const padding = priceRange * 0.1;
    const adjustedMin = minPrice - padding;
    const adjustedMax = maxPrice + padding;
    const adjustedRange = adjustedMax - adjustedMin;

    // Chart dimensions
    const chartWidth = rect.width - 60;
    const chartHeight = rect.height - 40;
    const chartLeft = 40;
    const chartTop = 20;

    // Draw grid
    ctx.strokeStyle = 'hsl(var(--trading-light))';
    ctx.lineWidth = 0.5;
    
    // Horizontal grid lines
    for (let i = 0; i <= 5; i++) {
      const y = chartTop + (chartHeight / 5) * i;
      ctx.beginPath();
      ctx.moveTo(chartLeft, y);
      ctx.lineTo(chartLeft + chartWidth, y);
      ctx.stroke();
      
      // Price labels
      const price = adjustedMax - (adjustedRange / 5) * i;
      ctx.fillStyle = 'hsl(var(--trading-muted))';
      ctx.font = '10px JetBrains Mono';
      ctx.textAlign = 'right';
      ctx.fillText(formatPrice(price, selectedPair), chartLeft - 5, y + 3);
    }

    // Vertical grid lines
    const timeStep = Math.max(1, Math.floor(candleData.length / 8));
    for (let i = 0; i < candleData.length; i += timeStep) {
      const x = chartLeft + (chartWidth / (candleData.length - 1)) * i;
      ctx.beginPath();
      ctx.moveTo(x, chartTop);
      ctx.lineTo(x, chartTop + chartHeight);
      ctx.stroke();
    }

    if (chartType === 'candlestick') {
      // Draw candlesticks
      const candleWidth = Math.max(2, chartWidth / candleData.length * 0.8);
      
      candleData.forEach((candle, index) => {
        const x = chartLeft + (chartWidth / (candleData.length - 1)) * index;
        const openY = chartTop + chartHeight - ((candle.open - adjustedMin) / adjustedRange) * chartHeight;
        const closeY = chartTop + chartHeight - ((candle.close - adjustedMin) / adjustedRange) * chartHeight;
        const highY = chartTop + chartHeight - ((candle.high - adjustedMin) / adjustedRange) * chartHeight;
        const lowY = chartTop + chartHeight - ((candle.low - adjustedMin) / adjustedRange) * chartHeight;
        
        const isGreen = candle.close >= candle.open;
        ctx.strokeStyle = isGreen ? 'hsl(var(--trading-success))' : 'hsl(var(--trading-danger))';
        ctx.fillStyle = isGreen ? 'hsl(var(--trading-success))' : 'hsl(var(--trading-danger))';
        ctx.lineWidth = 1;
        
        // Draw wick
        ctx.beginPath();
        ctx.moveTo(x, highY);
        ctx.lineTo(x, lowY);
        ctx.stroke();
        
        // Draw body
        const bodyTop = Math.min(openY, closeY);
        const bodyHeight = Math.abs(closeY - openY);
        
        if (isGreen) {
          ctx.fillRect(x - candleWidth / 2, bodyTop, candleWidth, Math.max(1, bodyHeight));
        } else {
          ctx.fillRect(x - candleWidth / 2, bodyTop, candleWidth, Math.max(1, bodyHeight));
        }
      });
    } else {
      // Draw line chart
      ctx.strokeStyle = 'hsl(var(--trading-success))';
      ctx.lineWidth = 2;
      ctx.beginPath();
      
      candleData.forEach((candle, index) => {
        const x = chartLeft + (chartWidth / (candleData.length - 1)) * index;
        const y = chartTop + chartHeight - ((candle.close - adjustedMin) / adjustedRange) * chartHeight;
        
        if (index === 0) {
          ctx.moveTo(x, y);
        } else {
          ctx.lineTo(x, y);
        }
      });
      
      ctx.stroke();
    }

  }, [candleData, chartType, selectedPair]);

  return (
    <Card className="bg-trading-gray rounded-xl p-6 h-96">
      <div className="flex items-center justify-between mb-4">
        <div className="flex items-center space-x-4">
          <h3 className="text-lg font-semibold">{selectedPair}</h3>
          <div className="flex items-center space-x-2">
            <Select value={timeframe} onValueChange={setTimeframe}>
              <SelectTrigger className="w-32 bg-trading-light border-trading-slate">
                <SelectValue />
              </SelectTrigger>
              <SelectContent className="bg-trading-light border-trading-slate">
                <SelectItem value="1m">1 Minute</SelectItem>
                <SelectItem value="5m">5 Minutes</SelectItem>
                <SelectItem value="15m">15 Minutes</SelectItem>
              </SelectContent>
            </Select>
            <div className="flex space-x-1">
              <Button
                variant={chartType === 'candlestick' ? 'default' : 'outline'}
                size="sm"
                onClick={() => setChartType('candlestick')}
                className="bg-trading-light hover:bg-trading-slate border-trading-slate"
              >
                <BarChart3 className="w-4 h-4" />
              </Button>
              <Button
                variant={chartType === 'line' ? 'default' : 'outline'}
                size="sm"
                onClick={() => setChartType('line')}
                className="bg-trading-light hover:bg-trading-slate border-trading-slate"
              >
                <TrendingUp className="w-4 h-4" />
              </Button>
            </div>
          </div>
        </div>
        <div className="flex items-center space-x-4">
          <div className="text-right">
            <div className="text-sm text-trading-muted">Current Price</div>
            <div className="font-mono text-xl font-semibold text-trading-success">
              {formatPrice(currentPrice, selectedPair)}
            </div>
          </div>
          <div className="text-right">
            <div className="text-sm text-trading-muted">Change</div>
            <div className={`font-mono text-lg ${priceChange >= 0 ? 'text-trading-success' : 'text-trading-danger'}`}>
              {formatPriceChange(priceChange, selectedPair)}
            </div>
          </div>
        </div>
      </div>
      
      <div className="relative h-full">
        <canvas
          ref={canvasRef}
          className="w-full h-full rounded"
          style={{ maxHeight: '300px' }}
        />
      </div>
    </Card>
  );
}
