import { Card } from '@/components/ui/card';
import { Badge } from '@/components/ui/badge';
import { Clock, TrendingUp, TrendingDown, Target } from 'lucide-react';
import { formatTimeShort, getSignalColor, getSignalBgColor } from '@/lib/utils';
import { useSignalUpdates } from '@/hooks/useWebSocket';
import { useQuery } from '@tanstack/react-query';
import type { Signal } from '@shared/schema';

export function LiveSignals() {
  const liveSignals = useSignalUpdates();
  
  const { data: recentSignals } = useQuery({
    queryKey: ['/api/signals/recent'],
    refetchInterval: 30000,
  });

  // Combine live signals with recent signals, removing duplicates
  const allSignals = [...liveSignals, ...(recentSignals || [])].slice(0, 10);

  return (
    <Card className="bg-trading-gray rounded-xl p-6">
      <div className="flex items-center justify-between mb-4">
        <h3 className="text-lg font-semibold">Live Signals</h3>
        <div className="text-sm text-trading-success font-mono flex items-center">
          <Target className="w-4 h-4 mr-1" />
          92% Accuracy
        </div>
      </div>
      
      <div className="space-y-3">
        {allSignals.length === 0 ? (
          <div className="text-center py-8 text-trading-muted">
            <Target className="w-12 h-12 mx-auto mb-2 opacity-50" />
            <p>Waiting for signals...</p>
            <p className="text-sm mt-1">Signals generate every minute based on market conditions</p>
          </div>
        ) : (
          allSignals.map((signal, index) => (
            <div
              key={`${signal.pair}-${signal.timestamp}-${index}`}
              className={`signal-card ${signal.direction.toLowerCase()}`}
            >
              <div className="flex items-center justify-between mb-2">
                <div className="flex items-center space-x-2">
                  <span className="font-semibold">{signal.pair}</span>
                  <Badge
                    className={`${getSignalBgColor(signal.direction)} ${
                      signal.direction === 'CALL' ? 'text-trading-dark' : 'text-white'
                    } font-semibold`}
                  >
                    {signal.direction === 'CALL' ? (
                      <TrendingUp className="w-3 h-3 mr-1" />
                    ) : (
                      <TrendingDown className="w-3 h-3 mr-1" />
                    )}
                    {signal.direction}
                  </Badge>
                </div>
                <div className="text-trading-warning font-mono font-semibold">
                  {signal.confidence}%
                </div>
              </div>
              
              <div className="text-sm text-trading-muted mb-2 flex items-center">
                <Clock className="w-3 h-3 mr-1" />
                {formatTimeShort(new Date(signal.timestamp))} UTC
              </div>
              
              <div className="flex flex-wrap gap-1">
                {signal.strategies.map((strategy, strategyIndex) => (
                  <span
                    key={strategyIndex}
                    className="strategy-badge"
                  >
                    {strategy}
                  </span>
                ))}
              </div>
              
              {signal.result && (
                <div className="mt-2 pt-2 border-t border-trading-slate flex items-center justify-between">
                  <span className={`text-sm font-semibold ${
                    signal.result === 'WIN' ? 'text-trading-success' : 'text-trading-danger'
                  }`}>
                    {signal.result}
                  </span>
                  {signal.pnl && (
                    <span className={`font-mono text-sm ${
                      signal.pnl > 0 ? 'text-trading-success' : 'text-trading-danger'
                    }`}>
                      {signal.pnl > 0 ? '+' : ''}${signal.pnl.toFixed(2)}
                    </span>
                  )}
                </div>
              )}
            </div>
          ))
        )}
      </div>
    </Card>
  );
}
