import { Card } from '@/components/ui/card';
import { Badge } from '@/components/ui/badge';
import { Progress } from '@/components/ui/progress';
import { Clock, Target, AlertTriangle, CheckCircle, TrendingUp, TrendingDown } from 'lucide-react';
import { formatCountdown, getSecondsUntilNextCandle } from '@/lib/utils';
import { useSignalUpdates, useTimeUpdates } from '@/hooks/useWebSocket';
import { useState, useEffect } from 'react';
import type { LiveSignal } from '@shared/schema';

export function TradeEntryGuide() {
  const signals = useSignalUpdates();
  const currentTime = useTimeUpdates();
  const [countdown, setCountdown] = useState(0);
  const [activeSignal, setActiveSignal] = useState<LiveSignal | null>(null);
  const [entryWindow, setEntryWindow] = useState<'waiting' | 'ready' | 'expired'>('waiting');

  // Update countdown timer
  useEffect(() => {
    const updateCountdown = () => {
      const seconds = getSecondsUntilNextCandle();
      setCountdown(seconds);
      
      // Entry window logic
      if (seconds >= 50) {
        setEntryWindow('waiting'); // Too early
      } else if (seconds >= 10) {
        setEntryWindow('ready'); // Perfect entry window
      } else {
        setEntryWindow('expired'); // Too late
      }
    };

    updateCountdown();
    const interval = setInterval(updateCountdown, 1000);
    
    return () => clearInterval(interval);
  }, []);

  // Update active signal
  useEffect(() => {
    if (signals.length > 0) {
      const latestSignal = signals[0];
      const signalAge = Date.now() - new Date(latestSignal.timestamp).getTime();
      
      // Signal is valid for 50 seconds
      if (signalAge < 50000) {
        setActiveSignal(latestSignal);
      } else {
        setActiveSignal(null);
      }
    }
  }, [signals]);

  const getEntryStatusColor = () => {
    switch (entryWindow) {
      case 'ready': return 'bg-trading-success';
      case 'waiting': return 'bg-trading-warning';
      case 'expired': return 'bg-trading-danger';
    }
  };

  const getEntryStatusText = () => {
    switch (entryWindow) {
      case 'ready': return 'ENTER TRADE NOW';
      case 'waiting': return 'WAIT FOR ENTRY';
      case 'expired': return 'TOO LATE - WAIT';
    }
  };

  const getTradeInstructions = () => {
    if (!activeSignal) {
      return {
        title: "Waiting for Signal",
        message: "No active signals. Wait for next high-confidence signal.",
        action: "Monitor indicators and be ready",
        urgency: "low"
      };
    }

    if (entryWindow === 'ready') {
      return {
        title: "🚨 TRADE NOW!",
        message: `Enter ${activeSignal.direction} position on ${activeSignal.pair}`,
        action: `Set 1-minute expiry, confidence: ${activeSignal.confidence}%`,
        urgency: "high"
      };
    }

    if (entryWindow === 'waiting') {
      return {
        title: "Signal Active - Prepare",
        message: `Get ready for ${activeSignal.direction} on ${activeSignal.pair}`,
        action: `Wait ${countdown - 10} seconds for entry window`,
        urgency: "medium"
      };
    }

    return {
      title: "Entry Window Closed",
      message: "Signal expired. Wait for next candle.",
      action: "Do not enter. Wait for new signal.",
      urgency: "low"
    };
  };

  const instructions = getTradeInstructions();

  return (
    <Card className="bg-trading-gray rounded-xl p-6">
      <div className="flex items-center justify-between mb-4">
        <h3 className="text-lg font-semibold flex items-center">
          <Target className="w-5 h-5 mr-2" />
          Trade Entry Guide
        </h3>
        <div className={`w-3 h-3 rounded-full ${getEntryStatusColor()} animate-pulse`}></div>
      </div>

      {/* Entry Window Status */}
      <div className="mb-6">
        <div className="flex items-center justify-between mb-2">
          <span className="text-sm text-trading-muted">Entry Window</span>
          <span className={`text-sm font-bold ${
            entryWindow === 'ready' ? 'text-trading-success' : 
            entryWindow === 'waiting' ? 'text-trading-warning' : 'text-trading-danger'
          }`}>
            {getEntryStatusText()}
          </span>
        </div>
        <div className="relative">
          <Progress 
            value={((60 - countdown) / 60) * 100} 
            className="h-3"
          />
          <div className="absolute inset-0 flex items-center justify-center">
            <span className="text-xs font-mono font-bold text-trading-dark">
              {formatCountdown(countdown)}
            </span>
          </div>
        </div>
        <div className="flex justify-between text-xs text-trading-muted mt-1">
          <span>Wait (50-60s)</span>
          <span className="text-trading-success font-bold">Enter (10-50s)</span>
          <span>Expired (0-10s)</span>
        </div>
      </div>

      {/* Active Signal Display */}
      {activeSignal && (
        <div className={`border-l-4 pl-4 mb-6 ${
          activeSignal.direction === 'CALL' ? 'border-trading-success' : 'border-trading-danger'
        }`}>
          <div className="flex items-center justify-between mb-2">
            <div className="flex items-center space-x-2">
              <span className="font-bold text-lg">{activeSignal.pair}</span>
              <Badge className={`${
                activeSignal.direction === 'CALL' ? 'bg-trading-success' : 'bg-trading-danger'
              } text-white font-bold`}>
                {activeSignal.direction === 'CALL' ? (
                  <TrendingUp className="w-3 h-3 mr-1" />
                ) : (
                  <TrendingDown className="w-3 h-3 mr-1" />
                )}
                {activeSignal.direction}
              </Badge>
            </div>
            <div className="text-right">
              <div className="text-2xl font-bold text-trading-warning">
                {activeSignal.confidence}%
              </div>
              <div className="text-xs text-trading-muted">Confidence</div>
            </div>
          </div>
          
          <div className="text-sm text-trading-muted mb-2">
            Strategies: {activeSignal.strategies.join(', ')}
          </div>
          
          <div className="text-xs text-trading-muted">
            Signal Age: {Math.floor((Date.now() - new Date(activeSignal.timestamp).getTime()) / 1000)}s
          </div>
        </div>
      )}

      {/* Trade Instructions */}
      <div className={`p-4 rounded-lg ${
        instructions.urgency === 'high' ? 'bg-trading-success/10 border border-trading-success' :
        instructions.urgency === 'medium' ? 'bg-trading-warning/10 border border-trading-warning' :
        'bg-trading-slate/50'
      }`}>
        <div className="flex items-center space-x-2 mb-2">
          {instructions.urgency === 'high' && <CheckCircle className="w-5 h-5 text-trading-success" />}
          {instructions.urgency === 'medium' && <Clock className="w-5 h-5 text-trading-warning" />}
          {instructions.urgency === 'low' && <AlertTriangle className="w-5 h-5 text-trading-muted" />}
          <h4 className={`font-bold ${
            instructions.urgency === 'high' ? 'text-trading-success' :
            instructions.urgency === 'medium' ? 'text-trading-warning' :
            'text-trading-muted'
          }`}>
            {instructions.title}
          </h4>
        </div>
        
        <p className="text-sm mb-2">{instructions.message}</p>
        <p className="text-xs text-trading-muted">{instructions.action}</p>
      </div>

      {/* Quick Entry Rules */}
      <div className="mt-6 pt-4 border-t border-trading-slate">
        <h5 className="font-semibold text-sm mb-3">Entry Rules</h5>
        <div className="space-y-2 text-xs">
          <div className="flex items-center space-x-2">
            <div className="w-2 h-2 bg-trading-success rounded-full"></div>
            <span>Only trade signals with 85%+ confidence</span>
          </div>
          <div className="flex items-center space-x-2">
            <div className="w-2 h-2 bg-trading-warning rounded-full"></div>
            <span>Enter between 10-50 seconds of new candle</span>
          </div>
          <div className="flex items-center space-x-2">
            <div className="w-2 h-2 bg-trading-danger rounded-full"></div>
            <span>Use 1-minute expiry (same candle close)</span>
          </div>
          <div className="flex items-center space-x-2">
            <div className="w-2 h-2 bg-trading-muted rounded-full"></div>
            <span>Risk 2-3% of account per trade</span>
          </div>
        </div>
      </div>
    </Card>
  );
}