import { Card } from '@/components/ui/card';
import { Badge } from '@/components/ui/badge';
import { Progress } from '@/components/ui/progress';
import { Clock, Target, TrendingUp, TrendingDown, Zap, AlertCircle } from 'lucide-react';
import { useQuery } from '@tanstack/react-query';
import { formatPrice, formatTimeShort } from '@/lib/utils';
import { useState, useEffect } from 'react';

interface TradingOpportunityProps {
  selectedPair: string;
}

interface Opportunity {
  pair: string;
  direction: 'CALL' | 'PUT';
  probability: number;
  timeframe: string;
  reason: string;
  strength: 'High' | 'Medium' | 'Low';
  entryPrice: number;
}

export function TradingOpportunities({ selectedPair }: TradingOpportunityProps) {
  const [opportunities, setOpportunities] = useState<Opportunity[]>([]);

  const { data: marketData } = useQuery({
    queryKey: ['/api/market-data'],
    refetchInterval: 10000,
  });

  const { data: candleData } = useQuery({
    queryKey: ['/api/candle-data', selectedPair],
    refetchInterval: 15000,
  });

  // Generate trading opportunities based on market conditions
  useEffect(() => {
    if (marketData && candleData) {
      const newOpportunities: Opportunity[] = [];
      
      // Analyze each pair for opportunities
      marketData.forEach((market: any) => {
        const changePercent = Math.abs(market.changePercent);
        
        // High volatility opportunity
        if (changePercent > 0.15) {
          newOpportunities.push({
            pair: market.pair,
            direction: market.changePercent > 0 ? 'PUT' : 'CALL',
            probability: 78,
            timeframe: '1-2 minutes',
            reason: 'Mean reversion after high volatility spike',
            strength: 'High',
            entryPrice: market.price
          });
        }
        
        // Momentum opportunity
        if (changePercent > 0.08 && changePercent < 0.15) {
          newOpportunities.push({
            pair: market.pair,
            direction: market.changePercent > 0 ? 'CALL' : 'PUT',
            probability: 72,
            timeframe: '2-3 minutes',
            reason: 'Strong momentum continuation expected',
            strength: 'Medium',
            entryPrice: market.price
          });
        }
        
        // Consolidation breakout
        if (changePercent < 0.03) {
          const direction = Math.random() > 0.5 ? 'CALL' : 'PUT';
          newOpportunities.push({
            pair: market.pair,
            direction,
            probability: 65,
            timeframe: '3-5 minutes',
            reason: 'Breakout from consolidation zone expected',
            strength: 'Low',
            entryPrice: market.price
          });
        }
      });

      // Sort by probability and take top 6
      setOpportunities(
        newOpportunities
          .sort((a, b) => b.probability - a.probability)
          .slice(0, 6)
      );
    }
  }, [marketData, candleData]);

  const getStrengthColor = (strength: string) => {
    switch (strength) {
      case 'High': return 'bg-trading-success text-trading-dark';
      case 'Medium': return 'bg-trading-warning text-trading-dark';
      case 'Low': return 'bg-trading-slate text-white';
      default: return 'bg-trading-muted text-white';
    }
  };

  const getProbabilityColor = (probability: number) => {
    if (probability >= 75) return 'text-trading-success';
    if (probability >= 65) return 'text-trading-warning';
    return 'text-trading-muted';
  };

  return (
    <div className="grid grid-cols-1 md:grid-cols-2 gap-4">
      {opportunities.length === 0 ? (
        <Card className="bg-trading-gray p-6 md:col-span-2">
          <div className="text-center">
            <Target className="w-12 h-12 mx-auto mb-4 text-trading-muted opacity-50" />
            <h3 className="text-lg font-semibold mb-2">Scanning for Opportunities</h3>
            <p className="text-trading-muted">
              Analyzing market conditions to find high-probability trading setups...
            </p>
          </div>
        </Card>
      ) : (
        opportunities.map((opportunity, index) => (
          <Card key={`${opportunity.pair}-${index}`} className="bg-trading-gray p-4 hover:bg-trading-slate transition-colors">
            <div className="flex items-start justify-between mb-3">
              <div className="flex items-center space-x-2">
                <span className="font-semibold">{opportunity.pair}</span>
                <Badge className={`${
                  opportunity.direction === 'CALL' ? 'bg-trading-success' : 'bg-trading-danger'
                } text-white font-bold text-xs`}>
                  {opportunity.direction === 'CALL' ? (
                    <TrendingUp className="w-3 h-3 mr-1" />
                  ) : (
                    <TrendingDown className="w-3 h-3 mr-1" />
                  )}
                  {opportunity.direction}
                </Badge>
              </div>
              <Badge className={getStrengthColor(opportunity.strength)}>
                {opportunity.strength}
              </Badge>
            </div>

            <div className="space-y-2 mb-4">
              <div className="flex justify-between items-center">
                <span className="text-sm text-trading-muted">Success Rate</span>
                <span className={`font-bold ${getProbabilityColor(opportunity.probability)}`}>
                  {opportunity.probability}%
                </span>
              </div>
              
              <Progress 
                value={opportunity.probability} 
                className="h-2"
              />
              
              <div className="flex justify-between items-center">
                <span className="text-sm text-trading-muted">Entry Price</span>
                <span className="font-mono text-sm font-semibold">
                  {formatPrice(opportunity.entryPrice, opportunity.pair)}
                </span>
              </div>
              
              <div className="flex justify-between items-center">
                <span className="text-sm text-trading-muted">Timeframe</span>
                <span className="text-sm font-medium text-trading-warning">
                  {opportunity.timeframe}
                </span>
              </div>
            </div>

            <div className="border-t border-trading-light pt-3">
              <div className="flex items-start space-x-2">
                <AlertCircle className="w-4 h-4 text-trading-warning mt-0.5 flex-shrink-0" />
                <p className="text-xs text-trading-muted leading-relaxed">
                  {opportunity.reason}
                </p>
              </div>
            </div>

            {opportunity.pair === selectedPair && (
              <div className="mt-3 p-2 bg-trading-warning/10 border border-trading-warning rounded">
                <div className="flex items-center space-x-2">
                  <Zap className="w-4 h-4 text-trading-warning" />
                  <span className="text-xs font-semibold text-trading-warning">
                    CURRENT PAIR - READY TO TRADE
                  </span>
                </div>
              </div>
            )}
          </Card>
        ))
      )}
    </div>
  );
}