import { useState, useEffect, useRef, useCallback } from 'react';
import type { LiveSignal, MarketData } from '@shared/schema';

interface WebSocketMessage {
  type: 'new_signals' | 'market_data_update' | 'price_updates' | 'time_update' | 'market_status' | 'signal_result_update';
  data: any;
}

interface UseWebSocketReturn {
  isConnected: boolean;
  lastMessage: WebSocketMessage | null;
  sendMessage: (message: any) => void;
  reconnect: () => void;
}

export function useWebSocket(): UseWebSocketReturn {
  const [isConnected, setIsConnected] = useState(false);
  const [lastMessage, setLastMessage] = useState<WebSocketMessage | null>(null);
  const ws = useRef<WebSocket | null>(null);
  const reconnectTimer = useRef<NodeJS.Timeout | null>(null);
  const isReconnecting = useRef(false);

  const connect = useCallback(() => {
    if (isReconnecting.current) return;
    
    try {
      const protocol = window.location.protocol === "https:" ? "wss:" : "ws:";
      const wsUrl = `${protocol}//${window.location.host}/ws`;
      
      ws.current = new WebSocket(wsUrl);
      
      ws.current.onopen = () => {
        console.log('WebSocket connected');
        setIsConnected(true);
        isReconnecting.current = false;
        
        // Clear any existing reconnect timer
        if (reconnectTimer.current) {
          clearTimeout(reconnectTimer.current);
          reconnectTimer.current = null;
        }
      };
      
      ws.current.onmessage = (event) => {
        try {
          const message: WebSocketMessage = JSON.parse(event.data);
          setLastMessage(message);
        } catch (error) {
          console.error('Failed to parse WebSocket message:', error);
        }
      };
      
      ws.current.onclose = (event) => {
        console.log('WebSocket disconnected:', event.code, event.reason);
        setIsConnected(false);
        
        // Attempt to reconnect after 3 seconds if not manually closed
        if (event.code !== 1000 && !isReconnecting.current) {
          isReconnecting.current = true;
          reconnectTimer.current = setTimeout(() => {
            console.log('Attempting to reconnect...');
            connect();
          }, 3000);
        }
      };
      
      ws.current.onerror = (error) => {
        console.error('WebSocket error:', error);
        setIsConnected(false);
      };
      
    } catch (error) {
      console.error('Failed to create WebSocket connection:', error);
      setIsConnected(false);
    }
  }, []);

  const sendMessage = useCallback((message: any) => {
    if (ws.current && ws.current.readyState === WebSocket.OPEN) {
      ws.current.send(JSON.stringify(message));
    } else {
      console.warn('WebSocket is not connected. Cannot send message.');
    }
  }, []);

  const reconnect = useCallback(() => {
    if (ws.current) {
      ws.current.close();
    }
    connect();
  }, [connect]);

  useEffect(() => {
    connect();
    
    return () => {
      isReconnecting.current = false;
      if (reconnectTimer.current) {
        clearTimeout(reconnectTimer.current);
      }
      if (ws.current) {
        ws.current.close(1000, 'Component unmounting');
      }
    };
  }, [connect]);

  return {
    isConnected,
    lastMessage,
    sendMessage,
    reconnect,
  };
}

// Custom hooks for specific data types
export function useSignalUpdates() {
  const { lastMessage } = useWebSocket();
  const [signals, setSignals] = useState<LiveSignal[]>([]);

  useEffect(() => {
    if (lastMessage?.type === 'new_signals') {
      const newSignals = lastMessage.data as LiveSignal[];
      setSignals(prev => {
        // Add new signals and keep only the last 10
        const updated = [...newSignals, ...prev].slice(0, 10);
        return updated;
      });
    }
  }, [lastMessage]);

  return signals;
}

export function useMarketDataUpdates() {
  const { lastMessage } = useWebSocket();
  const [marketData, setMarketData] = useState<MarketData[]>([]);

  useEffect(() => {
    if (lastMessage?.type === 'market_data_update') {
      setMarketData(lastMessage.data as MarketData[]);
    }
  }, [lastMessage]);

  return marketData;
}

export function usePriceUpdates() {
  const { lastMessage } = useWebSocket();
  const [priceUpdates, setPriceUpdates] = useState<{ pair: string; price: number }[]>([]);

  useEffect(() => {
    if (lastMessage?.type === 'price_updates') {
      setPriceUpdates(lastMessage.data);
    }
  }, [lastMessage]);

  return priceUpdates;
}

export function useTimeUpdates() {
  const { lastMessage } = useWebSocket();
  const [currentTime, setCurrentTime] = useState(new Date());

  useEffect(() => {
    if (lastMessage?.type === 'time_update') {
      setCurrentTime(new Date(lastMessage.data.timestamp));
    }
  }, [lastMessage]);

  return currentTime;
}

export function useMarketStatus() {
  const { lastMessage, isConnected } = useWebSocket();
  const [status, setStatus] = useState<'ACTIVE' | 'CLOSED' | 'CONNECTING'>('CONNECTING');

  useEffect(() => {
    if (!isConnected) {
      setStatus('CONNECTING');
    } else if (lastMessage?.type === 'market_status') {
      setStatus(lastMessage.data.status);
    } else if (isConnected) {
      setStatus('ACTIVE');
    }
  }, [lastMessage, isConnected]);

  return { status, isConnected };
}
